Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
src/cc_liquid/__init__.py | (no class) | 7 | 0 | 0 | 100%
src/cc_liquid/backtester.py | BacktestConfig | 0 | 0 | 0 | 100%
src/cc_liquid/backtester.py | BacktestResult | 0 | 0 | 0 | 100%
src/cc_liquid/backtester.py | Backtester | 175 | 40 | 0 | 77%
src/cc_liquid/backtester.py | BacktestOptimizer | 149 | 139 | 0 | 7%
src/cc_liquid/backtester.py | (no class) | 59 | 0 | 0 | 100%
src/cc_liquid/callbacks.py | CCLiquidCallbacks | 0 | 0 | 15 | 100%
src/cc_liquid/callbacks.py | NoOpCallbacks | 15 | 15 | 0 | 0%
src/cc_liquid/callbacks.py | PrintCallbacks | 32 | 32 | 0 | 0%
src/cc_liquid/callbacks.py | (no class) | 50 | 0 | 19 | 100%
src/cc_liquid/cli.py | (no class) | 540 | 540 | 0 | 0%
src/cc_liquid/cli_callbacks.py | RichCLICallbacks | 29 | 29 | 0 | 0%
src/cc_liquid/cli_callbacks.py | (no class) | 22 | 22 | 0 | 0%
src/cc_liquid/cli_display.py | (no class) | 890 | 890 | 4 | 0%
src/cc_liquid/completion.py | InstallResult | 0 | 0 | 0 | 100%
src/cc_liquid/completion.py | (no class) | 85 | 85 | 0 | 0%
src/cc_liquid/config.py | DataSourceConfig | 0 | 0 | 0 | 100%
src/cc_liquid/config.py | RebalancingConfig | 0 | 0 | 0 | 100%
src/cc_liquid/config.py | PortfolioConfig | 0 | 0 | 0 | 100%
src/cc_liquid/config.py | TWAPConfig | 0 | 0 | 0 | 100%
src/cc_liquid/config.py | StopLossConfig | 0 | 0 | 0 | 100%
src/cc_liquid/config.py | ExecutionConfig | 0 | 0 | 0 | 100%
src/cc_liquid/config.py | Config | 61 | 28 | 0 | 54%
src/cc_liquid/config.py | (no class) | 139 | 65 | 0 | 53%
src/cc_liquid/data_loader.py | DataSource | 1 | 1 | 0 | 0%
src/cc_liquid/data_loader.py | FileDataSource | 10 | 0 | 0 | 100%
src/cc_liquid/data_loader.py | DataFrameDataSource | 5 | 0 | 0 | 100%
src/cc_liquid/data_loader.py | DataLoader | 22 | 11 | 0 | 50%
src/cc_liquid/data_loader.py | (no class) | 20 | 0 | 0 | 100%
src/cc_liquid/order.py | Order | 0 | 0 | 0 | 100%
src/cc_liquid/order.py | OrderHistory | 8 | 1 | 0 | 88%
src/cc_liquid/order.py | OrderManager | 60 | 10 | 0 | 83%
src/cc_liquid/order.py | (no class) | 55 | 0 | 0 | 100%
src/cc_liquid/portfolio/__init__.py | (no class) | 2 | 0 | 0 | 100%
src/cc_liquid/portfolio/sizing.py | (no class) | 34 | 3 | 0 | 91%
src/cc_liquid/stop_loss.py | StopLossOrder | 0 | 0 | 0 | 100%
src/cc_liquid/stop_loss.py | StopLossManager | 121 | 69 | 0 | 43%
src/cc_liquid/stop_loss.py | (no class) | 31 | 0 | 0 | 100%
src/cc_liquid/trader.py | AccountInfo | 0 | 0 | 0 | 100%
src/cc_liquid/trader.py | Position | 0 | 0 | 0 | 100%
src/cc_liquid/trader.py | PortfolioInfo | 5 | 5 | 0 | 0%
src/cc_liquid/trader.py | CCLiquid | 453 | 453 | 0 | 0%
src/cc_liquid/trader.py | (no class) | 96 | 0 | 0 | 100%
Total |  | 3176 | 2438 | 38 | 23%

No items found using the specified filter.